==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1APIServiceStatusFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1APIServiceStatusFluent<A extends V1APIServiceStatusFluent<A>> extends Fluent<A>{


    public A addToConditions(int index,V1APIServiceCondition item);
    public A setToConditions(int index,V1APIServiceCondition item);
    public A addToConditions(V1APIServiceCondition... items);
    public A addAllToConditions(Collection<V1APIServiceCondition> items);
    public A removeFromConditions(V1APIServiceCondition... items);
    public A removeAllFromConditions(Collection<V1APIServiceCondition> items);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<V1APIServiceCondition> getConditions();
    public List<V1APIServiceCondition> buildConditions();
    public V1APIServiceCondition buildCondition(int index);
    public V1APIServiceCondition buildFirstCondition();
    public V1APIServiceCondition buildLastCondition();
    public V1APIServiceCondition buildMatchingCondition(io.kubernetes.client.fluent.Predicate<V1APIServiceConditionBuilder> predicate);
    public A withConditions(List<V1APIServiceCondition> conditions);
    public A withConditions(V1APIServiceCondition... conditions);
    public Boolean hasConditions();
    public V1APIServiceStatusFluent.ConditionsNested<A> addNewCondition();
    public V1APIServiceStatusFluent.ConditionsNested<A> addNewConditionLike(V1APIServiceCondition item);
    public V1APIServiceStatusFluent.ConditionsNested<A> setNewConditionLike(int index,V1APIServiceCondition item);
    public V1APIServiceStatusFluent.ConditionsNested<A> editCondition(int index);
    public V1APIServiceStatusFluent.ConditionsNested<A> editFirstCondition();
    public V1APIServiceStatusFluent.ConditionsNested<A> editLastCondition();
    public V1APIServiceStatusFluent.ConditionsNested<A> editMatchingCondition(io.kubernetes.client.fluent.Predicate<V1APIServiceConditionBuilder> predicate);

    public interface ConditionsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1APIServiceConditionFluent<V1APIServiceStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1APIServiceStatusFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1APIServiceStatusFluent<A extends V1APIServiceStatusFluent<A>> extends Fluent<A>{


    public A addToConditions(int index,V1APIServiceCondition item);
    public A setToConditions(int index,V1APIServiceCondition item);
    public A addToConditions(V1APIServiceCondition... items);
    public A addAllToConditions(Collection<V1APIServiceCondition> items);
    public A removeFromConditions(V1APIServiceCondition... items);
    public A removeAllFromConditions(Collection<V1APIServiceCondition> items);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<V1APIServiceCondition> getConditions();
    public List<V1APIServiceCondition> buildConditions();
    public V1APIServiceCondition buildCondition(int index);
    public V1APIServiceCondition buildFirstCondition();
    public V1APIServiceCondition buildLastCondition();
    public V1APIServiceCondition buildMatchingCondition(io.kubernetes.client.fluent.Predicate<V1APIServiceConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.kubernetes.client.fluent.Predicate<V1APIServiceConditionBuilder> predicate);
    public A withConditions(List<V1APIServiceCondition> conditions);
    public A withConditions(V1APIServiceCondition... conditions);
    public Boolean hasConditions();
    public V1APIServiceStatusFluent.ConditionsNested<A> addNewCondition();
    public V1APIServiceStatusFluent.ConditionsNested<A> addNewConditionLike(V1APIServiceCondition item);
    public V1APIServiceStatusFluent.ConditionsNested<A> setNewConditionLike(int index,V1APIServiceCondition item);
    public V1APIServiceStatusFluent.ConditionsNested<A> editCondition(int index);
    public V1APIServiceStatusFluent.ConditionsNested<A> editFirstCondition();
    public V1APIServiceStatusFluent.ConditionsNested<A> editLastCondition();
    public V1APIServiceStatusFluent.ConditionsNested<A> editMatchingCondition(io.kubernetes.client.fluent.Predicate<V1APIServiceConditionBuilder> predicate);

    public interface ConditionsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1APIServiceConditionFluent<V1APIServiceStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}


}
